@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::App::Command::dumpwith;
 
-our $VERSION = '0.002010';
+our $VERSION = '0.002011';
 
 # ABSTRACT: Dump all plugins that 'do' a certain role
 
@@ -161,7 +161,7 @@ Dist::Zilla::App::Command::dumpwith - Dump all plugins that 'do' a certain role
 
 =head1 VERSION
 
-version 0.002010
+version 0.002011
 
 =head1 SYNOPSIS
 
@@ -173,7 +173,7 @@ version 0.002010
 
 If you are using an HTML-enabled POD viewer, you should see a screenshot of this in action:
 
-( Everyone else can visit L<http://kentnl.github.io/Dist-Zilla-App-Command-dumpwith/media/example_01.png> )
+( Everyone else can visit L<http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/example_01.png> )
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -186,7 +186,12 @@ If you are using an HTML-enabled POD viewer, you should see a screenshot of this
 
 =end MetaPOD::JSON
 
-=for html <center><img src="http://kentnl.github.io/Dist-Zilla-App-Command-dumpwith/media/example_01.png" alt="Screenshot" width="806" height="438"/></center>
+=for html <center>
+  <img src="http://kentnl.github.io/screenshots/Dist-Zilla-App-Command-dumpwith/example_01.png"
+       alt="Screenshot"
+       width="806"
+       height="438"/>
+</center>
 
 =head1 DESCRIPTION
 
